Split the line as needed. Fix automatically, continue without asking.
**For dictionary variables:** Instead of skipping, split out long strings into
separate variables, split those lines and refer to them in the dictionaries.
**Note:** When splitting lines, never add a backslash (`\`). Use only
the `...` syntax for line continuation in Robot Framework.
